psi

Function psi 

pub fn psi(
    equation: &impl Equation,
    subjects: &Data,
    support_points: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>,
    error_models: &AssayErrorModels,
    progress: bool,
) -> Result<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>, PharmsolError>
👎Deprecated since 0.23.0: Use log_likelihood_matrix() instead and exponentiate if needed
Calculate the likelihood matrix (deprecated).

Deprecated: Use log_likelihood_matrix instead. This function exponentiates the log-likelihood matrix, which can cause numerical underflow for many observations or extreme parameter values.

This function is provided for backward compatibility with the old psi API.